<?php
$TRANSLATIONS = array(
"Could not load template" => "Não foi possivel carregar o modelo",
"Saved" => "Guardado",
"Reset" => "Repor",
"Sharing email (HTML)" => "Partilhar email (HTML)",
"Sharing email (plain text fallback)" => "Partilhar email (texto sem formatação)",
"Lost password mail" => "Perdi a palavra passe do mail",
"New user email (HTML)" => "Novo email de utilizador (HTML)",
"New user email (plain text fallback)" => "Novo email de utilizador (texto simples)",
"Activity notification mail" => "Email de notificação de actividade",
"Mail Templates" => "Templates de Emails",
"Theme" => "Tema",
"Template" => "Template",
"Please choose a template" => "Por favor escolha um modelo",
"Save" => "Guardar"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
